===
QDJ
===

QDJ is ``django-admin.py startproject``, but with your own templates.
The project starter for obsessives with deadlines.


Install qdj:
============
  ``# pip install qdj``

Create a project template:
==========================
  ``# qdj create``

  ``Created Django 1.3 template in /Users/nath/.qdj/1.3``

Check out the template:
=======================
  ``# cd ~/.qdj/1.3``

  ``# find``

  ``.``

  ``./hooks.py``

  ``./files``

  ``./files/settings.py``

  ``./files/manage.py``

  ``./files/urls.py``

  ``./files/__init__.py``

Add a dynamic requirements file:
================================
  ``# echo >>files/requirements.txt "django == {{ django_version }}"``

Start a new project using our template:
=======================================
  ``# cd /tmp``

  ``# qdj start myproject``

Show the created files:
=======================
  ``# find myproject``

  ``myproject``

  ``myproject/requirements.txt``

  ``myproject/settings.py``

  ``myproject/manage.py``

  ``myproject/urls.py``

  ``myproject/__init__.py``
